==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/lv.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Uzdevumi",
    "Due yesterday" : "Termiņš vakar",
    "Due today" : "Termiņš šodien",
    "Due tomorrow" : "Termiņš rīt",
    "Due on" : "Termiņš:",
    "Started yesterday" : "Sākās vakar",
    "Starts today" : "Sākas šodien",
    "Starts tomorrow" : "Sākas rīt",
    "Started on" : "Sākās:",
    "Starts on" : "Sākas:",
    "[Remind me yesterday at ]HH:mm" : "[Atgādināt vakar]HH:mm",
    "[Remind me today at ]HH:mm" : "[Atgādināt šodien]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Atgādināt rīt]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Atgādināt]MMM DD, YYYY, HH:mm",
    "Yesterday" : "Vakar",
    "Today" : "Šodien",
    "Tomorrow" : "Rīt",
    "in %s" : "iekš %s",
    "%s ago" : "Pirms %s",
    "seconds" : "sekundes",
    "a minute" : "minūte",
    "%d minutes" : "%d minūtes",
    "an hour" : "stunda",
    "%d hours" : "%d stundas",
    "a day" : "diena",
    "%d days" : "%d dienas",
    "a month" : "mēnesis",
    "%d months" : "%d mēneši",
    "a year" : "gads",
    "%d years" : "%d gadi",
    "week" : "nedēļa",
    "weeks" : "nedēļas",
    "day" : "diena",
    "days" : "dienas",
    "hour" : "stunda",
    "hours" : "stundas",
    "minute" : "minūte",
    "minutes" : "minūtes",
    "second" : "otrais",
    "before beginning" : "pirms sākuma",
    "after beginning" : "pēc sākuma",
    "before end" : "pirms beigām",
    "after end" : "pēc beigām",
    "Comment" : "Komentārs",
    "Add a comment" : "Pievienot komentāru",
    "This will delete the Calendar \"%s\" and all of its entries." : "Šis dzēsīs Kalendāru \"%s\" un visus tā ierakstus.",
    "The name \"%s\" is already used." : "Nosaukums \"%s\" jau tiek lietots.",
    "An empty name is not allowed." : "Nosaukums ir obligāts.",
    "Hidden" : "Paslēpts",
    "Visible" : "Redzams",
    "Automatic" : "Automātisks",
    "Sunday" : "Svētdiena",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Add an important item in \"%s\"..." : "Pievienot \"%s\" svarīgu uzdevumu",
    "Add an item due today in \"%s\"..." : "Pievienot \"%s\" ierakstu ar termiņu šodien ",
    "Add an item in \"%s\"..." : "Pievienot \"%s\" ierakstu",
    "Add a current item in \"%s\"..." : "Pievienot \"%s\" pašreizējo ierakstu",
    "Add a subtask to \"%s\"..." : "Pievienot apakšuzdevumu \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["neviena pabeigta uzdevuma","%n paeigts uzdevums","%n pabeigti uzvedumi"],
    "Hours" : "Stundas",
    "Minutes" : "Minūtes",
    "Set due date" : "Uzstādīt izpildes termiņu",
    "%s %% completed" : "%s %% izpildīti",
    "priority %s: " : "prioritāte %s:",
    "high" : "augsta",
    "medium" : "vidēja",
    "low" : "zema",
    "no priority assigned" : "nav piešķirta prioritāte",
    "Remind me" : "Atgādināt",
    "at the end" : "beigās",
    "at the beginning" : "sākumā",
    "Set start date" : "Uzstādīt sākuma datumu",
    "{calendar} shared by {owner}" : "{calendar} dalījās {owner}",
    "Unnamed" : "Nenosaukts",
    "Important" : "Svarīgi",
    "Week" : "Nedēļa",
    "All" : "Visi",
    "Current" : "Pašreizējais",
    "Completed" : "Pabeigts",
    "Delete" : "Dzēst",
    "Cancel" : "Atcelt",
    "Edit" : "Rediģēt",
    "Link" : "Saite",
    "Download" : "Lejupielādēt",
    "Save" : "Saglabāt",
    "Add List..." : "Pievienot sarakstu",
    "New List" : "Jauns saraksts",
    "Settings" : "Iestatījumi",
    "Start of week" : "Nedēļas sākums",
    "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
    "Change sort order" : "Mainīt kārtošanas secību",
    "Default" : "Noklusējuma",
    "Due date" : "Izpildes datums",
    "Start date" : "Sākuma datums",
    "Priority" : "Prioritāte",
    "Alphabetically" : "Alfabētiskā secībā",
    "Manually" : "Manuāli",
    "Load remaining completed tasks." : "Ielādēt pārējos pabeigtos uzdevumus.",
    "All day" : "Visas dienas",
    "(New category)" : "(Jauna kategorija)",
    "Select categories..." : "Atlasiet kategoriju...",
    "Loading the task..." : "Ielādē uzdevumu...",
    "Task not found!" : "Uzdevums nav atrasts!",
    "add a subtask to" : "pievienot apakšuzdevumu"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/lv.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Uzdevumi",
    "Due yesterday" : "Termiņš vakar",
    "Due today" : "Termiņš šodien",
    "Due tomorrow" : "Termiņš rīt",
    "Due on" : "Termiņš:",
    "Started yesterday" : "Sākās vakar",
    "Starts today" : "Sākas šodien",
    "Starts tomorrow" : "Sākas rīt",
    "Started on" : "Sākās:",
    "Starts on" : "Sākas:",
    "[Remind me yesterday at ]HH:mm" : "[Atgādināt vakar]HH:mm",
    "[Remind me today at ]HH:mm" : "[Atgādināt šodien]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Atgādināt rīt]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Atgādināt]MMM DD, YYYY, HH:mm",
    "Yesterday" : "Vakar",
    "Today" : "Šodien",
    "Tomorrow" : "Rīt",
    "in %s" : "iekš %s",
    "%s ago" : "Pirms %s",
    "seconds" : "sekundes",
    "a minute" : "minūte",
    "%d minutes" : "%d minūtes",
    "an hour" : "stunda",
    "%d hours" : "%d stundas",
    "a day" : "diena",
    "%d days" : "%d dienas",
    "a month" : "mēnesis",
    "%d months" : "%d mēneši",
    "a year" : "gads",
    "%d years" : "%d gadi",
    "week" : "nedēļa",
    "weeks" : "nedēļas",
    "day" : "diena",
    "days" : "dienas",
    "hour" : "stunda",
    "hours" : "stundas",
    "minute" : "minūte",
    "minutes" : "minūtes",
    "second" : "otrais",
    "before beginning" : "pirms sākuma",
    "after beginning" : "pēc sākuma",
    "before end" : "pirms beigām",
    "after end" : "pēc beigām",
    "Comment" : "Komentārs",
    "Add a comment" : "Pievienot komentāru",
    "This will delete the Calendar \"%s\" and all of its entries." : "Šis dzēsīs Kalendāru \"%s\" un visus tā ierakstus.",
    "The name \"%s\" is already used." : "Nosaukums \"%s\" jau tiek lietots.",
    "An empty name is not allowed." : "Nosaukums ir obligāts.",
    "Hidden" : "Paslēpts",
    "Visible" : "Redzams",
    "Automatic" : "Automātisks",
    "Sunday" : "Svētdiena",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Add an important item in \"%s\"..." : "Pievienot \"%s\" svarīgu uzdevumu",
    "Add an item due today in \"%s\"..." : "Pievienot \"%s\" ierakstu ar termiņu šodien ",
    "Add an item in \"%s\"..." : "Pievienot \"%s\" ierakstu",
    "Add a current item in \"%s\"..." : "Pievienot \"%s\" pašreizējo ierakstu",
    "Add a subtask to \"%s\"..." : "Pievienot apakšuzdevumu \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["neviena pabeigta uzdevuma","%n paeigts uzdevums","%n pabeigti uzvedumi"],
    "Hours" : "Stundas",
    "Minutes" : "Minūtes",
    "Set due date" : "Uzstādīt izpildes termiņu",
    "%s %% completed" : "%s %% izpildīti",
    "priority %s: " : "prioritāte %s:",
    "high" : "augsta",
    "medium" : "vidēja",
    "low" : "zema",
    "no priority assigned" : "nav piešķirta prioritāte",
    "Remind me" : "Atgādināt",
    "at the end" : "beigās",
    "at the beginning" : "sākumā",
    "Set start date" : "Uzstādīt sākuma datumu",
    "{calendar} shared by {owner}" : "{calendar} dalījās {owner}",
    "Unnamed" : "Nenosaukts",
    "Important" : "Svarīgi",
    "Week" : "Nedēļa",
    "All" : "Visi",
    "Current" : "Pašreizējais",
    "Completed" : "Pabeigts",
    "Delete" : "Dzēst",
    "Cancel" : "Atcelt",
    "Edit" : "Rediģēt",
    "Link" : "Saite",
    "Download" : "Lejupielādēt",
    "Save" : "Saglabāt",
    "Add List..." : "Pievienot sarakstu",
    "New List" : "Jauns saraksts",
    "Settings" : "Iestatījumi",
    "Start of week" : "Nedēļas sākums",
    "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
    "Change sort order" : "Mainīt kārtošanas secību",
    "Default" : "Noklusējuma",
    "Due date" : "Izpildes datums",
    "Start date" : "Sākuma datums",
    "Priority" : "Prioritāte",
    "Alphabetically" : "Alfabētiskā secībā",
    "Manually" : "Manuāli",
    "Load remaining completed tasks." : "Ielādēt pārējos pabeigtos uzdevumus.",
    "Task is completed" : "Uzdevums pabeigts",
    "All day" : "Visas dienas",
    "(New category)" : "(Jauna kategorija)",
    "Select categories..." : "Atlasiet kategoriju...",
    "Loading the task..." : "Ielādē uzdevumu...",
    "Task not found!" : "Uzdevums nav atrasts!",
    "add a subtask to" : "pievienot apakšuzdevumu",
    "Toggle subtasks" : "Pārslēgt apakšuzdevumus",
    "Toggle completed subtasks" : "Pārslēgt pabeigtos apakšuzdevumus"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
